@@ -135,6 +135,15 @@ def test_aqua_redhat_json():
         return json.loads(fp.read())
 
 
+@pytest.fixture
+def test_aqua_redhat2_json():
+    test_cve_data = os.path.join(
+        os.path.dirname(os.path.realpath(__file__)), "data", "CVE-2022-21824.json"
+    )
+    with open(test_cve_data, "r") as fp:
+        return json.loads(fp.read())
+
+
 @pytest.fixture
 def test_aqua_arch_json():
     test_cve_data = os.path.join(
@@ -330,6 +339,7 @@ def test_aqua_convert(
     test_aqua_ubuntu2_json,
     test_aqua_ubuntu3_json,
     test_aqua_redhat_json,
+    test_aqua_redhat2_json,
     test_aqua_arch_json,
     test_aqua_opensuse_json,
     test_aqua_suse_json,
@@ -357,6 +367,9 @@ def test_aqua_convert(
     assert cve_data
     cve_data = aqualatest.convert(test_aqua_redhat_json)
     assert cve_data
+    cve_data = aqualatest.convert(test_aqua_redhat2_json)
+    assert cve_data
+    assert len(cve_data) == 7
     cve_data = aqualatest.convert(test_aqua_arch_json)
     assert cve_data
     cve_data = aqualatest.convert(test_aqua_opensuse_json)
