@@ -436,6 +436,87 @@ def test_debian_build_compare3():
     assert res
 
 
+def test_redhat_build_compare():
+    data = """
+1.18.2-21.el8 1.18.2-22.el8_7
+1.11.948 1.12.261
+2.12.1 2.12.6.1, 2.13.2.1
+2.12.1 2.12.7.1, 2.13.4.1
+2.12.1 2.12.7.1, 2.13.4
+2.8.6 2.8.9
+25.1-android 30.0
+1.25.0 1.31.0
+1.25.0 1.33.3
+3.16.1 3.16.3, 3.19.6, 3.20.3, 3.21.7
+2.6 2.7
+1.10.9 1.9.16, 1.10.11
+1.10.9 1.9.16, 1.10.11
+6.5.0 6.6.0
+1.20 1.21
+1.20 1.21
+1.20 1.21
+1.20 1.21
+1.9 1.10.0
+2.3.0 2.5.1
+1.5.21 1.6.0
+1.14.3 1.15.3
+2.13.3 2.13.9
+1.28 1.31
+1.28 1.31
+1.28 1.31
+1.28 1.31
+1.28 1.32
+1.30 1.31
+1.30 1.31
+1.30 1.31
+1.30 1.31
+1.30 1.32
+6.7.1 11.8.5, 12.1.0
+1.0.0 4.0.1, 3.0.1
+1.7.1 2.4.0
+1.25.11 1.26.5
+v0.0.0-20210421170649-83a5a9bb288b 0.0.0-20211202192323-5770296d904e
+v0.0.0-20210421170649-83a5a9bb288b 0.0.0-20220314234659-1baeb1ce4c0b
+v0.0.0-20210326060303-6b1517762897 0.0.0-20210520170846-37e1c6afe023
+v0.0.0-20210326060303-6b1517762897 0.0.0-20211209124913-491a49abca63
+v0.0.0-20210326060303-6b1517762897 0.0.0-20220906165146-f3363e06e74c
+v0.0.0-20210326060303-6b1517762897 0.0.0-20210428140749-89ef3d95e781
+v0.0.0-20210502180810-71e4cd670f79 0.0.0-20220412211240-33da011f77ad
+v0.0.0-20200622213623-75b288015ac9 0.0.0-20201216223049-8b5274cf687f
+v0.0.0-20200622213623-75b288015ac9 0.0.0-20211202192323-5770296d904e
+v0.0.0-20200622213623-75b288015ac9 0.0.0-20220314234659-1baeb1ce4c0b
+v0.0.0-20210520170846-37e1c6afe023 0.0.0-20211209124913-491a49abca63
+v0.0.0-20210520170846-37e1c6afe023 0.0.0-20220906165146-f3363e06e74c
+v0.0.0-20210630005230-0f9fa26af87c 0.0.0-20220412211240-33da011f77ad
+v0.3.6 0.3.7
+v0.3.6 0.3.8
+v0.2.0 v0.3.1
+v1.11.0 1.11.1
+v0.0.0-20210921065528-437939a70204 0.0.0-20220412211240-33da011f77ad
+v0.0.0-20211019181941-9d821ace8654 0.0.0-20220412211240-33da011f77ad
+v0.0.0-20210421170649-83a5a9bb288b 0.0.0-20211202192323-5770296d904e
+v0.0.0-20210421170649-83a5a9bb288b 0.0.0-20220314234659-1baeb1ce4c0b
+v0.0.0-20210405180319-a5a99cb37ef4 0.0.0-20210520170846-37e1c6afe023
+v0.0.0-20210405180319-a5a99cb37ef4 0.0.0-20211209124913-491a49abca63
+v0.0.0-20210405180319-a5a99cb37ef4 0.0.0-20220906165146-f3363e06e74c
+v0.0.0-20210405180319-a5a99cb37ef4 0.0.0-20210428140749-89ef3d95e781
+v0.0.0-20210616094352-59db8d763f22 0.0.0-20220412211240-33da011f77ad
+v0.3.7 0.3.8
+"""
+    for line in data.split("\n"):
+        tmpA = line.split(" ")
+        if len(tmpA) != 2:
+            continue
+        res = utils.version_compare(tmpA[0], 0, "*", None, tmpA[1])
+        assert res
+        res = utils.version_compare(tmpA[1], 0, "*", None, tmpA[0])
+        assert not res
+    res = utils.version_compare("14.20.1", 0, "*", None, "12")
+    assert not res
+    res = utils.version_compare("6.0", 0, "*", None, "5.4")
+    assert not res
+
+
 def test_parse_uri():
     vendor, package, version, cve_type = utils.parse_cpe(
         "cpe:2.3:o:google:android:9.0:*:*:*:*:*:*:*"
