@@ -181,8 +181,8 @@ class AquaSource(NvdSource):
         fix_version_end_including = ""
         fix_version_start_excluding = ""
         fix_version_end_excluding = ""
-        fix_version_start_including = packages[0].get("version")
-        version_end_excluding = packages[0].get("version")
+        fix_version_start_including = packages[0].get("version").split(":")[-1]
+        version_end_excluding = packages[0].get("version").split(":")[-1]
         publishedDate = ""
         if cve_data.get("issued_date", {}).get("$date"):
             try:
@@ -260,7 +260,11 @@ class AquaSource(NvdSource):
         lastModifiedDate = cve_data.get("updated", {}).get("date")
         done_pkgs = {}
         for apkg in packages:
-            pkg_key = f"""{apkg.get("name")}:{apkg.get("version")}"""
+            version = apkg.get("version")
+            # Remove epoch
+            if ":" in version:
+                version = version.split(":")[-1]
+            pkg_key = f"""{apkg.get("name")}:{version}"""
             if done_pkgs.get(pkg_key):
                 continue
             pkg_name = apkg.get("name")
@@ -270,8 +274,8 @@ class AquaSource(NvdSource):
             fix_version_end_including = ""
             fix_version_start_excluding = ""
             fix_version_end_excluding = ""
-            fix_version_start_including = apkg.get("version")
-            version_end_excluding = apkg.get("version")
+            fix_version_start_including = version
+            version_end_excluding = version
 
             if pkg_name and fix_version_start_including:
                 tdata = config.CVE_TPL % dict(
@@ -450,11 +454,28 @@ class AquaSource(NvdSource):
             pkg_key = arelease.get("package")
             if done_pkgs.get(pkg_key):
                 continue
-            tmpA = pkg_key.split("-")
+            tmpA = pkg_key.split(":" if ":" in pkg_key else "-")
             if len(tmpA) < 2:
                 continue
             pkg_name = tmpA[0]
-            version = pkg_key.replace(pkg_name + "-", "")
+            if pkg_name.endswith("-0"):
+                pkg_name = pkg_name[0:-2]
+            version = ""
+            if ":" in pkg_key:
+                version = pkg_key.split(":")[-1]
+            else:
+                version = pkg_key.replace(pkg_name + "-", "")
+            # Remove epoch
+            if ":" in version:
+                version = version.split(":")[-1]
+            edition = "*"
+            cpe = arelease.get("cpe", "")
+            if cpe and cpe.startswith("cpe:"):
+                tmpc = cpe.split(":")
+                if len(tmpc) > 2:
+                    edition = f"{tmpc[-2]}-{tmpc[-1]}"
+                    if edition.startswith("-el"):
+                        edition = edition.replace("-el", "enterprise_linux-")
             version_start_including = ""
             version_end_including = version
             version_start_excluding = ""
@@ -474,7 +495,7 @@ class AquaSource(NvdSource):
                     vendor="redhat",
                     product=pkg_name,
                     version="*",
-                    edition="*",
+                    edition=edition,
                     version_start_including=version_start_including,
                     version_end_including=version_end_including,
                     version_start_excluding=version_start_excluding,
@@ -665,11 +686,11 @@ class AquaSource(NvdSource):
         version_start_including = ""
         version_end_including = ""
         version_start_excluding = ""
-        version_end_excluding = cve_data.get("res_ver")
+        version_end_excluding = cve_data.get("res_ver").split(":")[-1]
         fix_version_end_including = ""
         fix_version_start_excluding = ""
         fix_version_end_excluding = ""
-        fix_version_start_including = cve_data.get("res_ver")
+        fix_version_start_including = cve_data.get("res_ver").split(":")[-1]
         if pkg_name and version_end_excluding:
             tdata = config.CVE_TPL % dict(
                 cve_id=cve_id,
